@@ -13,7 +13,11 @@ def is_root(ctx, param, value):
     if os.geteuid() == 0:
         return True
     else:
-        raise click.BadParameter(f'You should run command from root user')
+        ctx.abort("""
+        ==========================
+        You should run command from root user!!!
+        ==========================
+        """)
 
 
 def validate_url(ctx, param, value):
